@@ -30,8 +30,6 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-markable.h>
 
-#include "sexy-icon-entry.h"
-
 #include <glib/gi18n.h>
 
 #include <gdk/gdkkeysyms.h>
@@ -106,22 +104,28 @@ send_focus_change (GtkWidget *widget,
 {
         GdkEvent *fevent = gdk_event_new (GDK_FOCUS_CHANGE);
 
+#if !GTK_CHECK_VERSION (2,21,0)
         g_object_ref (widget);
 
         if (in)
                 GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
         else
                 GTK_WIDGET_UNSET_FLAGS (widget, GTK_HAS_FOCUS);
+#endif
 
         fevent->focus_change.type = GDK_FOCUS_CHANGE;
-        fevent->focus_change.window = g_object_ref (widget->window);
+        fevent->focus_change.window = g_object_ref (gtk_widget_get_window (widget));
         fevent->focus_change.in = in;
-
+#if !GTK_CHECK_VERSION (2,21,0)
         gtk_widget_event (widget, fevent);
 
         g_object_notify (G_OBJECT (widget), "has-focus");
 
         g_object_unref (widget);
+#else
+	gtk_widget_send_focus_change (widget, fevent);
+#endif
+
         gdk_event_free (fevent);
 }
 
@@ -194,7 +198,7 @@ dma_sparse_view_goto_position_func (DmaSparseView *view)
 {
 	gint x, y;
 	gint win_x, win_y;
-	GdkWindow *window = GTK_WIDGET (view)->window;
+	GdkWindow *window = gtk_widget_get_window (GTK_WIDGET (view));
 	GdkScreen *screen = gdk_drawable_get_screen (window);
 	gint monitor_num;
 	GdkRectangle monitor;
@@ -218,35 +222,38 @@ dma_sparse_view_goto_activate (GtkWidget   *menu_item,
 	GtkWidget *toplevel;
 	GtkWidget *frame;
 	GtkWidget *vbox;
-	GtkWidget *icon;
+	GtkWindowGroup *toplevel_group, *goto_window_group;
 	
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (view));
+	toplevel_group = gtk_window_get_group (GTK_WINDOW (toplevel));
 	
 	if (view->priv->goto_window != NULL)
 	{
-		if (GTK_WINDOW (toplevel)->group)
-			gtk_window_group_add_window (GTK_WINDOW (toplevel)->group,
-										 GTK_WINDOW (view->priv->goto_window)); 
-		else if (GTK_WINDOW (view->priv->goto_window)->group)
-			gtk_window_group_remove_window (GTK_WINDOW (view->priv->goto_window)->group,
-											GTK_WINDOW (view->priv->goto_window)); 
+		goto_window_group = gtk_window_get_group (GTK_WINDOW (view->priv->goto_window));
+
+		if (toplevel_group)
+			gtk_window_group_add_window (toplevel_group,
+						     GTK_WINDOW (view->priv->goto_window));
+		else if (goto_window_group)
+			gtk_window_group_remove_window (goto_window_group,
+							GTK_WINDOW (view->priv->goto_window));
 	
 	}
 	else
 	{
 		view->priv->goto_window = gtk_window_new (GTK_WINDOW_POPUP);
 
-		if (GTK_WINDOW (toplevel)->group)
-			gtk_window_group_add_window (GTK_WINDOW (toplevel)->group,
-										 GTK_WINDOW (view->priv->goto_window));
+		if (toplevel_group)
+			gtk_window_group_add_window (toplevel_group,
+						     GTK_WINDOW (view->priv->goto_window));
 
 		gtk_window_set_modal (GTK_WINDOW (view->priv->goto_window), TRUE);
 		g_signal_connect (view->priv->goto_window, "delete_event",
-						  G_CALLBACK (dma_sparse_view_goto_delete_event),
-						  view);
+				  G_CALLBACK (dma_sparse_view_goto_delete_event),
+				  view);
 		g_signal_connect (view->priv->goto_window, "key_press_event",
-						  G_CALLBACK (dma_sparse_view_goto_key_press_event),
-						  view);
+				  G_CALLBACK (dma_sparse_view_goto_key_press_event),
+				  view);
   
 		frame = gtk_frame_new (NULL);
 		gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
@@ -259,14 +266,13 @@ dma_sparse_view_goto_activate (GtkWidget   *menu_item,
 		gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
 
 		/* add entry */
-		view->priv->goto_entry = sexy_icon_entry_new ();
-		icon = gtk_image_new_from_stock (GTK_STOCK_JUMP_TO, GTK_ICON_SIZE_MENU);
-		sexy_icon_entry_set_icon (SEXY_ICON_ENTRY(view->priv->goto_entry),
-    	                          SEXY_ICON_ENTRY_PRIMARY,
-                                  GTK_IMAGE (icon));
+		view->priv->goto_entry = gtk_entry_new ();
+		gtk_entry_set_icon_from_stock (GTK_ENTRY (view->priv->goto_entry),
+									   GTK_ENTRY_ICON_PRIMARY,
+									   GTK_STOCK_JUMP_TO);
 		gtk_widget_show (view->priv->goto_entry);
 		gtk_container_add (GTK_CONTAINER (vbox),
-						   view->priv->goto_entry);
+				   view->priv->goto_entry);
 					   
 		gtk_widget_realize (view->priv->goto_entry);
 	}
@@ -276,8 +282,8 @@ dma_sparse_view_goto_activate (GtkWidget   *menu_item,
 	gtk_widget_show (view->priv->goto_window);
 	
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (view), FALSE);
-    gtk_widget_grab_focus (view->priv->goto_entry);
-    send_focus_change (view->priv->goto_entry, TRUE);
+	gtk_widget_grab_focus (view->priv->goto_entry);
+	send_focus_change (view->priv->goto_entry, TRUE);
 	gtk_editable_set_position (GTK_EDITABLE (view->priv->goto_entry), -1);
 }
 
@@ -488,7 +494,7 @@ dma_sparse_view_populate_popup (DmaSparseView *view,
 	gtk_widget_show (menu_item);
 
 	/* create goto menu_item. */
-	menu_item = gtk_menu_item_new_with_mnemonic (_("_Goto address"));
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Go to address"));
 	g_signal_connect (G_OBJECT (menu_item), "activate",
 			  G_CALLBACK (dma_sparse_view_goto_activate), view);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
@@ -546,18 +552,19 @@ dma_sparse_view_synchronize_iter (DmaSparseView *view, DmaSparseIter *iter)
 
 	if (dist != 0)
 	{
-		if ((dist < 4.0 * (view->priv->vadjustment->page_size))
-			 && (dist > -4.0 * (view->priv->vadjustment->page_size)))
-        {
-			gint count = (gint)(dist / view->priv->vadjustment->step_increment);
-			
-        	dma_sparse_iter_forward_lines (iter, count);
-        }
-        else
+		gdouble page_size = gtk_adjustment_get_page_size (view->priv->vadjustment);
+
+		if ((dist < 4.0 * page_size) && (dist > -4.0 * page_size))
 		{
-        	dma_sparse_iter_move_at (iter, pos);
-            dma_sparse_iter_round (iter, FALSE);
-        }
+			gint count = (gint) (dist / gtk_adjustment_get_step_increment (view->priv->vadjustment));
+
+			dma_sparse_iter_forward_lines (iter, count);
+		}
+		else
+		{
+			dma_sparse_iter_move_at (iter, pos);
+			dma_sparse_iter_round (iter, FALSE);
+		}
 		gtk_adjustment_set_value (view->priv->vadjustment, (gdouble)dma_sparse_iter_get_address (iter));
 	}
 }
@@ -748,9 +755,9 @@ dma_sparse_view_paint_margin (DmaSparseView *view,
 			g_snprintf (str, sizeof (str),"0x%0*lX", margin_length, (long unsigned int)address);
 			pango_layout_set_markup (layout, str, -1);
 
-			gtk_paint_layout (GTK_WIDGET (view)->style,
+			gtk_paint_layout (gtk_widget_get_style (GTK_WIDGET (view)),
 					  win,
-					  GTK_WIDGET_STATE (view),
+					  gtk_widget_get_state (GTK_WIDGET (view)),
 					  FALSE,
 					  NULL,
 					  GTK_WIDGET (view),
@@ -806,10 +813,14 @@ dma_sparse_view_update_adjustement (DmaSparseView *view)
 	if (view->priv->vadjustment != NULL)
 	{
 		GtkAdjustment *vadj = view->priv->vadjustment;
+		gdouble step_increment, page_size;
+
+		step_increment = view->priv->char_by_line;
+		page_size = (view->priv->line_by_page - 1) * step_increment;
 		
-		vadj->step_increment = view->priv->char_by_line;
-		vadj->page_size = (view->priv->line_by_page - 1) * vadj->step_increment;
-		vadj->page_increment = vadj->page_size * 0.9;
+		gtk_adjustment_set_step_increment (vadj, step_increment);
+		gtk_adjustment_set_page_size (vadj, page_size);
+		gtk_adjustment_set_page_increment (vadj, page_size * 0.9);
 		gtk_adjustment_changed (vadj); 
 	}
 }
@@ -853,9 +864,9 @@ dma_sparse_view_set_scroll_adjustments (GtkTextView *text_view,
                         G_CALLBACK (dma_sparse_view_value_changed),
 						view);
 			
-			vadj->upper = dma_sparse_buffer_get_upper (view->priv->buffer);
-			vadj->lower = dma_sparse_buffer_get_lower (view->priv->buffer);
-			vadj->value = 0;
+			gtk_adjustment_set_upper (vadj, dma_sparse_buffer_get_upper (view->priv->buffer));
+			gtk_adjustment_set_lower (vadj, dma_sparse_buffer_get_lower (view->priv->buffer));
+			gtk_adjustment_set_value (vadj, 0);
 		}
 		view->priv->vadjustment = vadj;
 		dma_sparse_view_update_adjustement (view);
